@@ -4,9 +4,6 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-## ----setup--------------------------------------------------------------------
-library(broomExtra)
-
 ## ----list, echo = FALSE, message = FALSE--------------------------------------
 # loading the needed libraries
 library(dplyr)
@@ -33,3 +30,6 @@ method_df("tidy") %>%
   dplyr::mutate_all(.tbl = ., .funs = tidyr::replace_na, "") %>%
   knitr::kable()
 
+## -----------------------------------------------------------------------------
+insight::supported_models()
+
